@@ -7,9 +7,7 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
   if((length(g) == 0) && ((length(sigma2)==0) ||  (length(pii)==0) || (ncol(Abetas)==0) ))  stop("The model is not specified correctly.\n")
   if((length(g)!= 0) && (g < 1)) stop("g must be greater than 0.\n")
 
-  p    <- c()
-  for(j in 1:g) {p[j]    <- ncol(x[[j]])}
-
+  p    <- ncol(x)
   n    <- length(y)
 
   Lim1 <- y
@@ -23,7 +21,7 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
   {
     start.time     <- Sys.time()
     mu             <- matrix(0,n,g)
-    for(k in 1:g){mu[,k]<- x[[k]]%*%Abetas[[k]]}
+    for(k in 1:g){mu[,k]<- x%*%Abetas[,k]}
 
     criterio       <- 1
     count          <- 0
@@ -35,12 +33,11 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
       #print(count)
 
       tal          <- matrix(0, n, g)
+      soma1        <- matrix(0, p,1)
+      soma2        <- matrix(0, p, p)
 
       for (j in 1:g)
       {
-        soma1      <- matrix(0, p[j],1)
-        soma2      <- matrix(0, p[j], p[j])
-
         ### E-step: calculando os momentos
         NCensEUY   <- NCensurEsperUY(y,mu[,j],sigma2[j],nu=NULL,0,type="Normal")
 
@@ -63,14 +60,14 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
         tal[,j]    <- d1*pii[j]/d2
 
         ### M-step: atualizar os parametros ###
-        pii[j]      <- (1/n)*sum(tal[,j])
-        sigma2[j]   <- sum(tal[,j]*(u2-2*u1*mu[,j]+u0*mu[,j]^2))/sum(tal[,j])
-        soma1       <- t(x[[j]])%*%diag(tal[,j])%*%u1
-        soma2       <- t(x[[j]])%*%diag(tal[,j]*u0)%*%x[[j]]
-        Abetas[[j]] <- solve(soma2)%*%soma1
-        mu[,j]      <- x[[j]]%*%Abetas[[j]]
+        pii[j]     <- (1/n)*sum(tal[,j])
+        sigma2[j]  <- sum(tal[,j]*(u2-2*u1*mu[,j]+u0*mu[,j]^2))/sum(tal[,j])
+        soma1      <- t(x)%*%diag(tal[,j])%*%u1
+        soma2      <- t(x)%*%diag(tal[,j]*u0)%*%x
+        Abetas[,j] <- solve(soma2)%*%soma1
+        mu[,j]     <- x%*%Abetas[,j]
       } #End ---> for (j in 1:g)
-      #print(sigma2)
+
       pii[g]       <- 1 - (sum(pii) - pii[g])
       zero.pos     <- NULL
       zero.pos     <- which(pii == 0)
@@ -83,7 +80,7 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
       if (pii[1]< 0.5 & g==2)
       {
         mu         <- cbind(mu[,2],mu[,1])
-        #Abetas     <- list(Abetas[[2]], Abetas[[1]])
+        Abetas     <- cbind(Abetas[,2], Abetas[,1])
         pii        <- as.vector(c(pii[2], pii[1]))
         sigma2     <- as.vector(c(sigma2[2], sigma2[1]))
       }
@@ -111,27 +108,29 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
     #}
     end.time       <- Sys.time()
     time.taken     <- end.time - start.time
-
     EP              <- im.fmr.smn.cr(cc, y,x,Abetas,sigma2,pii,nu,family)$EP
-    parameters      <- cbind(c(do.call(c, Abetas),pii[1:(g-1)],sigma2))
+    print(Abetas)
+    print(class(Abetas))
+    print(pii)
+    print(sigma2)
+    parameters      <- cbind(c(do.call(c, as.list(Abetas) ),pii[1:(g-1)],sigma2))
     table           <- data.frame(parameters,EP)
     colnames(table) <- c("Estimate","Std. Error")
 
     k <- 0
     namesrowAbetas   <- c()
     for(j in 1:g)
-     for(i in 1:length(Abetas[[j]]))
-     {
-       k <- k + 1
-       namesrowAbetas[k] <- paste("beta",i-1,j,sep="")
-     }
+      for(i in 1:length(Abetas[,j]))
+      {
+        k <- k + 1
+        namesrowAbetas[k] <- paste("beta",i-1,j,sep="")
+      }
     namesrowSigmas   <- c(); for(i in 1:g){namesrowSigmas[i] <- paste("sigma",i,sep="")}
     namesrowPii      <- c(); for(i in 1:(g-1)){namesrowPii[i]  <- paste("pii",i,sep="")}
     rownames(table) <- c(namesrowAbetas,namesrowPii,namesrowSigmas)
   }
 
 
-
   ################################################################################
   ###                                     Student-t
   ################################################################################
@@ -141,11 +140,11 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
     start.time     <- Sys.time()
     ERRO           <- 1e-6
     TOLERANCIA     <- 1e-6
-    MAX_NU         <- 20
+    MAX_NU         <- 5
     MIN_NU         <- 1.01
     mu             <- matrix(0,n,g)
 
-    for (k in 1:g){mu[,k]<- x[[k]]%*%Abetas[[k]]}
+    for (k in 1:g){mu[,k]<- x%*%Abetas[,k]}
 
     criterio       <- 1
     count          <- 0
@@ -158,12 +157,11 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
       #print(count)
 
       tal          <- matrix(0, n, g)
+      soma1        <- matrix(0, p,1)
+      soma2        <- matrix(0, p, p)
 
       for(j in 1:g)
       {
-        soma1      <- matrix(0, p[j],1)
-        soma2      <- matrix(0, p[j], p[j])
-
         ### E-step: calculando os momentos
         NCensEUY   <- NCensurEsperUY(y,mu[,j],sigma2[j],nu,0,type="T")
         u0         <- NCensEUY$EUY0
@@ -185,14 +183,14 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
 
         ### M-step: atualizar os parametros ###
         pii[j]     <- (1/n)*sum(tal[,j])
-        sigma2[j]  <- sum(tal[,j]*(u2-2*u1*mu[,j]+u0*mu[,j]^2))/sum(tal[,j])
-        soma1      <- t(x[[j]])%*%diag(tal[,j])%*%u1
-        soma2      <- t(x[[j]])%*%diag(c(u0)*tal[,j])%*%x[[j]]
+        sigma2[j]  <- sum(tal[,j]*(u2-2*u1*mu[,j]+u0*mu[,j]^2)) /sum(tal[,j])
+        soma1      <- t(x)%*%diag(tal[,j])%*%u1
+        soma2      <- t(x)%*%diag(c(u0)*tal[,j])%*%x
 
-        Abetas[[j]]<- solve(soma2)%*%soma1
-        mu[,j]     <- x[[j]]%*%Abetas[[j]]
+        Abetas[,j] <- solve(soma2)%*%soma1
+        mu[,j]     <- x%*%Abetas[,j]
       }#End ---> for (j in 1:g)
-      #print(sigma2)
+
       pii[g]       <- 1 - (sum(pii) - pii[g])
       zero.pos     <- NULL
       zero.pos     <- which(pii == 0)
@@ -206,11 +204,11 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
       if (pii[1]< 0.5 & g==2)
       {
         mu         <- cbind(mu[,2],mu[,1])
-        #Abetas     <- list(Abetas[[2]], Abetas[[1]])
+        Abetas     <- cbind(Abetas[,2], Abetas[,1])
         pii        <- as.vector(c(pii[2], pii[1]))
         sigma2     <- as.vector(c(sigma2[2], sigma2[1]))
       }
-      #print(Abetas)
+
       ft           <- function(nu)sum(log(d.mixedT(cc, y, pii, mu, sigma2,nu)))
       nu           <- optimize(f=ft, interval=c(MIN_NU,MAX_NU),lower = MIN_NU, upper=MAX_NU,maximum=TRUE,tol=TOLERANCIA)$maximum
 
@@ -239,15 +237,14 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
     time.taken     <- end.time - start.time
 
     EP              <- im.fmr.smn.cr(cc, y,x,Abetas,sigma2,pii,nu,family)$EP
-    parameters      <- cbind(c(do.call(c, Abetas),pii[1:(g-1)],sigma2,nu))
+    parameters      <- cbind(c(do.call(c, as.list(Abetas)),pii[1:(g-1)],sigma2,nu))
     table           <- data.frame(parameters,c(EP,0))
     colnames(table) <- c("Estimate","Std. Error")
 
-
     k <- 0
     namesrowAbetas   <- c()
     for(j in 1:g)
-      for(i in 1:length(Abetas[[j]]))
+      for(i in 1:length(Abetas[,j]))
       {
         k <- k + 1
         namesrowAbetas[k] <- paste("beta",i-1,j,sep="")
@@ -266,13 +263,13 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
   if (family == "Slash")
   {
     start.time     <- Sys.time()
-    ERRO           <- 1e-8
-    TOLERANCIA     <- 1e-8
-    MAX_NU         <- 20
+    ERRO           <- 1e-6
+    TOLERANCIA     <- 1e-6
+    MAX_NU         <- 5
     MIN_NU         <- 1.01
     mu             <- matrix(0,n,g)
 
-    for (k in 1:g){mu[,k]<- x[[k]]%*%Abetas[[k]]}
+    for (k in 1:g){mu[,k]<- x%*%Abetas[,k]}
 
     criterio       <- 1
     count          <- 0
@@ -281,18 +278,17 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
 
     while((criterio > error) && (count <= iter.max))
     {
-      count        <- count + 1
+      count <- count + 1
       #print(count)
 
       tal          <- matrix(0, n, g)
+      soma1        <- matrix(0, p,1)
+      soma2        <- matrix(0, p, p)
 
       for (j in 1:g)
       {
-        soma1      <- matrix(0, p[j],1)
-        soma2      <- matrix(0, p[j], p[j])
-
-        ### E-step: calculando os momentos
-        NCensEUY   <- NCensurEsperUY(y,mu[,j],sigma2[j],nu,0,type="Slash")
+        j  ### E-step: calculando os momentos
+        NCensEUY   <- NCensurEsperUY(as.numeric(y),mu[,j],sigma2[j],nu,0,type="Slash")
         u0         <- NCensEUY$EUY0
         u1         <- NCensEUY$EUY1
         u2         <- NCensEUY$EUY2
@@ -301,7 +297,6 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
         u0[cc==1]  <- CensEUY$EUY0
         u1[cc==1]  <- CensEUY$EUY1
         u2[cc==1]  <- CensEUY$EUY2
-        #print(sum(u0))
 
         d1         <- dSL(cc, y, mu[,j], sigma2[j],nu)
         if(length(which(d1 == 0)) > 0) d1[which(d1 == 0)] <- .Machine$double.xmin
@@ -313,13 +308,14 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
         ### M-step: atualizar os parametros ###
 
         pii[j]     <- (1/n)*sum(tal[,j])
-        sigma2[j]  <- sum(tal[,j]*(u2-2*u1*mu[,j]+u0*mu[,j]^2))/sum(tal[,j])
-        soma1      <- t(x[[j]])%*%diag(tal[,j])%*%u1
-        soma2      <- t(x[[j]])%*%diag(c(u0)*tal[,j])%*%x[[j]]
-        Abetas[[j]]<- solve(soma2)%*%soma1
-        mu[,j]     <- x[[j]]%*%Abetas[[j]]
+        sigma2[j]  <- sum(tal[,j]*(u2-2*u1*mu[,j]+u0*mu[,j]^2)) /sum(tal[,j])
+        soma1      <- t(x)%*%diag(tal[,j])%*%u1
+        soma2      <- t(x)%*%diag(c(u0)*tal[,j])%*%x
+
+        Abetas[,j] <- solve(soma2)%*%soma1
+        mu[,j]     <- x%*%Abetas[,j]
       }
-      #print(sigma2)
+
       pii[g]       <- 1 - (sum(pii) - pii[g])
       zero.pos     <- NULL
       zero.pos     <- which(pii == 0)
@@ -329,17 +325,17 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
         pii[which(pii == max(pii))] <- max(pii) - sum(pii[zero.pos])
       }
 
-      #if(pii[1]< 0.5 & g==2)
-      #{
-      #  mu         <- cbind(mu[,2],mu[,1])
-      #  Abetas     <- list(Abetas[,2], Abetas[,1])
-      #  pii        <- as.vector(c(pii[2], pii[1]))
-      # sigma2     <- as.vector(c(sigma2[2], sigma2[1]))
-      #}
+      if(pii[1]< 0.5 & g==2)
+      {
+        mu         <- cbind(mu[,2],mu[,1])
+        Abetas     <- cbind(Abetas[,2], Abetas[,1])
+        pii        <- as.vector(c(pii[2], pii[1]))
+        sigma2     <- as.vector(c(sigma2[2], sigma2[1]))
+      }
 
       ft           <- function(nu)sum(log(d.mixedSL(cc, y, pii, mu, sigma2,nu)))
       nu           <- optimize(f=ft, interval=c(MIN_NU,MAX_NU),lower = MIN_NU, upper=MAX_NU,maximum=TRUE,tol=TOLERANCIA)$maximum
-      #print(nu)
+
       auxlog       <- d.mixedSL(cc, y, pii, mu, sigma2,nu)
       if(length(which(auxlog == 0)) > 0) auxlog[which(auxlog == 0)] <- .Machine$double.xmin
 
@@ -359,21 +355,21 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
 
     #if (criteria == TRUE){
       cl <- apply(tal, 1, which.max)
-      #    icl <- 0
-      #    for (j in 1:g) icl<-icl+sum(log(pii[j]*dSL(cc, y, mu[,j], sigma2[j],nu)))
+      #icl <- 0
+      #for (j in 1:g) icl<-icl+sum(log(pii[j]*dSL(cc, y, mu[,j], sigma2[j],nu)))
     #}
     end.time       <- Sys.time()
     time.taken     <- end.time - start.time
 
-    EP              <- im.fmr.smn.cr(cc, y,x,Abetas,sigma2,pii,nu,family)$EP
-    parameters      <- cbind(c(do.call(c, Abetas),pii[1:(g-1)],sigma2,nu))
+    EP              <- im.fmr.smn.cr(cc, y,x,Abetas,sigma2,pii,nu,family)$EP;print(EP)
+    parameters      <- cbind(c(do.call(c, as.list(Abetas) ),pii[1:(g-1)],sigma2,nu))
     table           <- data.frame(parameters,c(EP,0))
     colnames(table) <- c("Estimate","Std. Error")
 
     k <- 0
     namesrowAbetas   <- c()
     for(j in 1:g)
-      for(i in 1:length(Abetas[[j]]))
+      for(i in 1:length(Abetas[,j]))
       {
         k <- k + 1
         namesrowAbetas[k] <- paste("beta",i-1,j,sep="")
@@ -391,9 +387,10 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
   if (family == "NormalC")
   {
     start.time     <- Sys.time()
+    nu             <-  c(0.1,0.1)
     mu             <- matrix(0,n,g)
 
-    for (k in 1:g){mu[,k]<- x[[k]]%*%Abetas[[k]]}
+    for (k in 1:g){mu[,k]<- x%*%Abetas[,k]}
 
     criterio       <- 1
     count          <- 0
@@ -406,13 +403,13 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
       #print(count)
 
       tal          <- matrix(0, n, g)
+      soma1        <- matrix(0, p,1)
+      soma2        <- matrix(0, p, p)
 
       for (j in 1:g)
       {
-        soma1      <- matrix(0, p[j],1)
-        soma2      <- matrix(0, p[j], p[j])
-
         ### E-step: calculando os momentos
+
         NCensEUY   <- NCensurEsperUY(y,mu[,j],sigma2[j],nu,0,type="NormalC")
         u0         <- NCensEUY$EUY0
         u1         <- NCensEUY$EUY1
@@ -435,11 +432,11 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
 
         pii[j]     <- (1/n)*sum(tal[,j])
         sigma2[j]  <- sum(tal[,j]*(u2-2*u1*mu[,j]+u0*mu[,j]^2))/sum(tal[,j])
-        soma1      <- t(x[[j]])%*%diag(tal[,j])%*%u1
-        soma2      <- t(x[[j]])%*%diag(c(u0)*tal[,j])%*%x[[j]]
+        soma1      <- t(x)%*%diag(tal[,j])%*%u1
+        soma2      <- t(x)%*%diag(c(u0)*tal[,j])%*%x
 
-        Abetas[[j]]<- solve(soma2)%*%soma1
-        mu[,j]     <- x[[j]]%*%Abetas[[j]]
+        Abetas[,j] <- solve(soma2)%*%soma1
+        mu[,j]     <- x%*%Abetas[,j]
       }
 
       pii[g]       <- 1 - (sum(pii) - pii[g])
@@ -455,11 +452,24 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
       if (pii[1]< 0.5 & g==2)
       {
         mu         <- cbind(mu[,2],mu[,1])
-        #Abetas     <- cbind(Abetas[,2], Abetas[,1])
+        Abetas     <- cbind(Abetas[,2], Abetas[,1])
         pii        <- as.vector(c(pii[2], pii[1]))
         sigma2     <- as.vector(c(sigma2[2], sigma2[1]))
       }
 
+      ft <- function(nu)
+      {
+        a1         <- exp(nu[1])/(1+exp(nu[1]))
+        a2         <- exp(nu[2])/(1+exp(nu[2]))
+        resp       <- -sum(log(d.mixedCN(cc, y, pii, mu, sigma2,c(a1,a2))))
+        return(resp)
+      }
+
+      #Art          <- optim(c(0.1,0.1),ft, method=c("BFGS"),control=list(maxit=20000))$par
+      #nu3          <- min(round(exp(Art[1])/(1+exp(Art[1]))+0.05,1),0.9)
+      #nu4          <- min(round(exp(Art[2])/(1+exp(Art[2]))+0.05,1),0.9)
+      #nu           <- c(nu3,nu4)
+
       ft2          <- function(nu)sum(log(d.mixedCN(cc, y, pii, mu, sigma2,nu)))
       nu           <- optim(nu, ft2, control = list(fnscale = -1), method = "L-BFGS-B", lower = rep(0.01, 2), upper = rep(0.99,2))$par
       #print(nuu)
@@ -481,14 +491,15 @@ algEM.fmr.smn.cr <- function(cc, y, x, Abetas = NULL, sigma2 = NULL, pii = NULL,
     #if (criteria == TRUE)
     #{
       cl     <- apply(tal, 1, which.max)
-      #     icl <- 0
-      #     for (j in 1:g) icl<-icl+sum(log(pii[j]*dCN(cc, y, mu[,j], sigma2[j],nu)))
+      #  icl <- 0
+      #for (j in 1:g) icl<-icl+sum(log(pii[j]*dCN(cc, y, mu[,j], sigma2[j],nu)))
     #}
+    #nu <- nuu
     end.time       <- Sys.time()
     time.taken     <- end.time - start.time
 
     EP              <- im.fmr.smn.cr(cc, y,x,Abetas,sigma2,pii,nu,family)$EP
-    parameters      <- cbind(c(do.call(c, Abetas),pii[1:(g-1)],sigma2,nu))
+    parameters      <- cbind(c(do.call(c, as.list(Abetas) ),pii[1:(g-1)],sigma2,nu))
     table           <- data.frame(parameters,c(EP,0,0))
     colnames(table) <- c("Estimate","Std. Error")
 
